@@ -3,6 +3,7 @@
 import random
 import string
 
+from v2ray_util import run_type
 from ..util_core.v2ray import restart
 from ..util_core.writer import StreamWriter, GroupWriter
 from ..util_core.selector import GroupSelector, CommonSelector
@@ -27,7 +28,8 @@ class StreamModifier:
             (StreamType.MTPROTO, "MTProto"), 
             (StreamType.SS, "Shadowsocks"),
             (StreamType.QUIC, "Quic"),
-            (StreamType.VLESS, "VLESS"),
+            (StreamType.VLESS_TCP, "VLESS_TCP"),
+            (StreamType.VLESS_TLS, "VLESS_TLS"),
             (StreamType.VLESS_WS, "VLESS_WS"),
             (StreamType.VLESS_XTLS, "VLESS_XTLS"),
             (StreamType.TROJAN, "Trojan"),
@@ -65,7 +67,7 @@ class StreamModifier:
             print("")
             header = CommonSelector(header_type_list(), _("please select fake header: ")).select()
             kw = {'security': security, 'key': key, 'header': header}
-        elif sType in (StreamType.VLESS, StreamType.VLESS_WS, StreamType.VLESS_XTLS):
+        elif sType in (StreamType.VLESS_TLS, StreamType.VLESS_WS, StreamType.VLESS_XTLS):
             port_set = all_port()
             if not "443" in port_set:
                 print()
@@ -138,7 +140,7 @@ def modify(group=None, sType=None):
             choice = int(choice)
             if choice > 0 and choice <= len(sm.stream_type):
                 if sm.stream_type[choice - 1][1] in ("MTProto", "Shadowsocks") and group.tls == 'tls':
-                    print(_("V2ray MTProto/Shadowsocks not support https, close tls success!"))
+                    print(_("{} MTProto/Shadowsocks not support https, close tls success!".format(run_type.capitalize())))
                 sm.select(sm.stream_type[choice - 1][0])
                 print(_("modify protocol success"))
                 if need_restart:
