@@ -67,7 +67,8 @@ class StreamType(Enum):
     KCP_DTLS = 'dtls'
     KCP_WECHAT = 'wechat'
     KCP_WG = 'wireguard'
-    VLESS = 'vless'
+    VLESS_TCP = 'vless_tcp'
+    VLESS_TLS = 'vless_tls'
     VLESS_WS = 'vless_ws'
     VLESS_XTLS = 'vless_xtls'
     TROJAN = 'trojan'
@@ -76,8 +77,7 @@ def header_type_list():
     return ("none", "srtp", "utp", "wechat-video", "dtls", "wireguard")
 
 def ss_method():
-    return ("aes-256-cfb", "aes-128-cfb", "chacha20", 
-        "chacha20-ietf", "aes-256-gcm", "aes-128-gcm", "chacha20-poly1305")
+    return ("aes-256-gcm", "aes-128-gcm", "chacha20-poly1305")
 
 def xtls_flow():
     return ("", "xtls-rprx-origin", "xtls-rprx-direct")
